@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -22,7 +22,6 @@
 #include "graph_selectors.hh"
 #include "graph_properties.hh"
 
-#include <boost/mpl/quote.hpp>
 #include <boost/graph/breadth_first_search.hpp>
 
 #include <cmath>
@@ -245,10 +244,16 @@ void get_cts(GraphInterface& gi, GraphInterface& tgi, boost::any otpos,
     beprop_t beta = boost::any_cast<beprop_t>(obeta);
 
     gt_dispatch<>()
-        (std::bind(do_get_cts(), std::placeholders::_1, std::placeholders::_2,
-                   std::placeholders::_3, beta, cts, is_tree, max_depth),
-         graph_tool::all_graph_views(),
-         graph_tool::always_directed(),
-         vertex_scalar_vector_properties())
-        (gi.get_graph_view(), tgi.get_graph_view(), otpos);
+        (
+            [&](auto&& graph, auto&& a2, auto&& a3)
+            {
+                return do_get_cts()
+                    (std::forward<decltype(graph)>(graph),
+                     std::forward<decltype(a2)>(a2),
+                     std::forward<decltype(a3)>(a3), beta, cts, is_tree,
+                     max_depth);
+            },
+            graph_tool::all_graph_views(), graph_tool::always_directed(),
+            vertex_scalar_vector_properties())(gi.get_graph_view(),
+                                               tgi.get_graph_view(), otpos);
 }
