@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -44,7 +44,6 @@ min(const T1& v1, const T2& v2)
 }
 }
 
-#include <boost/bind.hpp>
 
 using namespace graph_tool;
 using namespace boost;
@@ -96,10 +95,15 @@ void kolmogorov_max_flow(GraphInterface& gi, size_t src, size_t sink,
                          boost::any capacity, boost::any res)
 {
     run_action<graph_tool::detail::always_directed, boost::mpl::true_>()
-        (gi, std::bind(get_kolmogorov_max_flow(),
-                       std::placeholders::_1, gi.get_edge_index(), gi.get_edge_index_range(),
-                       gi.get_vertex_index(), src, sink,  std::placeholders::_2,
-                       std::placeholders::_3),
-         writable_edge_scalar_properties(), writable_edge_scalar_properties())
-        (capacity,res);
+        (gi,
+         [&](auto&& graph, auto&& a2, auto&& a3)
+         {
+             return get_kolmogorov_max_flow()
+                 (std::forward<decltype(graph)>(graph), gi.get_edge_index(),
+                  gi.get_edge_index_range(), gi.get_vertex_index(), src, sink,
+                  std::forward<decltype(a2)>(a2),
+                  std::forward<decltype(a3)>(a3));
+         },
+         writable_edge_scalar_properties(),
+         writable_edge_scalar_properties())(capacity, res);
 }
