@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -21,8 +21,6 @@
 #include "graph_selectors.hh"
 #include "graph_properties.hh"
 
-#include <boost/bind.hpp>
-#include <boost/bind/placeholders.hpp>
 #include <boost/mpl/push_back.hpp>
 #include <boost/python.hpp>
 
@@ -100,12 +98,16 @@ void community_network(GraphInterface& gi, GraphInterface& cgi,
         vweight = no_vweight_map_t();
 
     run_action<>()
-        (gi, std::bind(get_community_network_vertices_dispatch(),
-                       std::placeholders::_1, std::ref(cgi.get_graph()),
-                       std::placeholders::_2, condensed_community_property,
-                       std::placeholders::_3, vertex_count),
-         writable_vertex_properties(), vweight_properties())
-        (community_property, vweight);
+        (gi,
+         [&](auto&& graph, auto&& a2, auto&& a3)
+         {
+             return get_community_network_vertices_dispatch()
+                 (std::forward<decltype(graph)>(graph), cgi.get_graph(),
+                  std::forward<decltype(a2)>(a2), condensed_community_property,
+                  std::forward<decltype(a3)>(a3), vertex_count);
+         },
+         writable_vertex_properties(),
+         vweight_properties())(community_property, vweight);
 
     community_network_edges(gi, cgi, community_property,
                             condensed_community_property, edge_count,
