@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -15,7 +15,7 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-#define BOOST_PYTHON_MAX_ARITY 40
+#define BOOST_PYTHON_MAX_ARITY 20
 
 #include "graph.hh"
 #include "graph_util.hh"
@@ -64,10 +64,14 @@ void generate_graph(GraphInterface& gi, size_t N,
         gi.set_directed(false);
 
     run_action<graph_views>()
-        (gi, std::bind(gen_graph(), std::placeholders::_1, N,
-                       PythonFuncWrap(deg_sample),
-                       no_parallel, no_self_loops,
-                       std::ref(rng), verbose, verify))();
+        (gi,
+         [&](auto&& graph)
+         {
+             return gen_graph()
+                 (std::forward<decltype(graph)>(graph), N,
+                  PythonFuncWrap(deg_sample), no_parallel, no_self_loops, rng,
+                  verbose, verify);
+         })();
 }
 
 void generate_sbm(GraphInterface& gi, boost::any ab, boost::python::object ors,
@@ -75,6 +79,17 @@ void generate_sbm(GraphInterface& gi, boost::any ab, boost::python::object ors,
                   boost::any ain_deg, boost::any aout_deg, bool micro_ers,
                   bool micro_degs, rng_t& rng);
 
+void generate_knn(GraphInterface& gi, boost::python::object om, size_t k,
+                  double r, double epsilon, bool cache, boost::any aw,
+                  rng_t& rng);
+
+void generate_knn_exact(GraphInterface& gi, boost::python::object om, size_t k,
+                        boost::any aw);
+
+void generate_triadic_closure(GraphInterface& gi, boost::any acurr,
+                              boost::any aego, boost::any oEs, bool probs,
+                              rng_t& rng);
+
 size_t random_rewire(GraphInterface& gi, string strat, size_t niter,
                      bool no_sweep, bool self_loops, bool parallel_edges,
                      bool configuration, bool traditional, bool micro,
@@ -131,6 +146,9 @@ BOOST_PYTHON_MODULE(libgraph_tool_generation)
     docstring_options dopt(true, false);
     def("gen_graph", &generate_graph);
     def("gen_sbm", &generate_sbm);
+    def("gen_knn", &generate_knn);
+    def("gen_knn_exact", &generate_knn_exact);
+    def("gen_triadic_closure", &generate_triadic_closure);
     def("random_rewire", &random_rewire);
     def("predecessor_graph", &predecessor_graph);
     def("line_graph", &line_graph);
