@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -28,6 +28,11 @@ using namespace graph_tool;
 void price(GraphInterface& gi, size_t N, double gamma, double c, size_t m,
            rng_t& rng)
 {
-    run_action<>()(gi, std::bind(get_price(), std::placeholders::_1, N, gamma, c, m,
-                                 std::ref(rng)))();
+    run_action<>()
+        (gi,
+         [&](auto&& graph)
+         {
+             return get_price()
+                 (std::forward<decltype(graph)>(graph), N, gamma, c, m, rng);
+         })();
 }
