@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -20,9 +20,6 @@
 
 #include "graph_union.hh"
 
-#include <boost/bind.hpp>
-
-#include <boost/python/extract.hpp>
 
 using namespace graph_tool;
 using namespace boost;
@@ -37,9 +34,14 @@ boost::python::tuple graph_union(GraphInterface& ugi, GraphInterface& gi,
     vprop_t vprop = boost::any_cast<vprop_t>(avprop);
     eprop_t eprop(gi.get_edge_index());
     gt_dispatch<boost::mpl::true_>()
-        (std::bind(graph_tool::graph_union(),
-                   std::placeholders::_1, std::placeholders::_2, vprop, eprop),
-         always_directed(), always_directed())
-        (ugi.get_graph_view(), gi.get_graph_view());
+        (
+            [&](auto&& graph, auto&& a2)
+            {
+                return graph_tool::graph_union()
+                    (std::forward<decltype(graph)>(graph),
+                     std::forward<decltype(a2)>(a2), vprop, eprop);
+            },
+            always_directed(),
+            always_directed())(ugi.get_graph_view(), gi.get_graph_view());
     return boost::python::make_tuple(avprop, boost::any(eprop));
 }
