@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -20,10 +20,6 @@
 
 #include "graph_union.hh"
 
-#include <boost/bind.hpp>
-
-#include <boost/python/extract.hpp>
-
 using namespace graph_tool;
 using namespace boost;
 
@@ -39,10 +35,14 @@ void vertex_property_union(GraphInterface& ugi, GraphInterface& gi,
     eprop_t eprop = any_cast<eprop_t>(p_eprop);
 
     gt_dispatch<>()
-        (std::bind(graph_tool::property_union(), std::placeholders::_1,
-                   std::placeholders::_2, vprop, eprop, std::placeholders::_3,
-                   prop),
-         always_directed(), always_directed(),
-         writable_vertex_properties())
-        (ugi.get_graph_view(), gi.get_graph_view(), uprop);
+        (
+            [&](auto&& graph, auto&& a2, auto&& a3)
+            {
+                return graph_tool::property_union()
+                    (std::forward<decltype(graph)>(graph),
+                     std::forward<decltype(a2)>(a2), vprop, eprop,
+                     std::forward<decltype(a3)>(a3), prop);
+            },
+            always_directed(), always_directed(), writable_vertex_properties())(
+            ugi.get_graph_view(), gi.get_graph_view(), uprop);
 }
