@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -393,8 +393,13 @@ struct graph_type_name
 string get_graph_type(GraphInterface& g)
 {
     string name;
-    run_action<>()(g, std::bind(graph_type_name(), std::placeholders::_1,
-                                std::ref(name)))();
+    run_action<>()
+        (g,
+         [&](auto&& graph)
+         {
+             return graph_type_name()
+                 (std::forward<decltype(graph)>(graph), name);
+         })();
     return name;
 }
 
