@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -22,8 +22,7 @@
 #include <boost/iostreams/filtering_stream.hpp>
 #include <boost/iostreams/filter/gzip.hpp>
 #include <boost/iostreams/filter/bzip2.hpp>
-#include <boost/iostreams/device/file_descriptor.hpp>
-#include <boost/iostreams/device/file.hpp>
+#include <boost/algorithm/string/predicate.hpp>
 #include <boost/graph/graphml.hpp>
 #include <boost/lexical_cast.hpp>
 #include <boost/xpressive/xpressive.hpp>
@@ -115,14 +114,9 @@ public:
     std::streamsize write(const char* s, std::streamsize n)
     {
         string buf(s, s+n);
-#if (PY_MAJOR_VERSION >= 3)
-        // in python 3 we need to construct a 'bytes' instance
         PyObject* bytes = PyBytes_FromStringAndSize(s, n);
         boost::python::handle<> x(bytes);
         boost::python::object pbuf(x);
-#else
-        boost::python::str pbuf(buf);
-#endif
         _file.attr("write")(pbuf);
         return n;
     }
@@ -519,30 +513,34 @@ void GraphInterface::write_to_file(string file, boost::python::object pfile,
             {
                 // vertex indexes must be between the [0, HardNumVertices(g)] range
                 vector_property_map<size_t> index_map(_vertex_index);
-                run_action<>()(*this, std::bind(generate_index(),
-                                                std::placeholders::_1,
-                                                index_map))();
-                run_action<>()(*this, std::bind(do_write_to_binary_file(),
-                                                std::ref(stream),
-                                                std::placeholders::_1,
-                                                index_map,
-                                                get_num_vertices(),
-                                                directed,
-                                                std::ref(agprops),
-                                                std::ref(avprops),
-                                                std::ref(aeprops)))();
+                run_action<>()
+                    (*this,
+                     [&](auto&& graph)
+                     {
+                         return generate_index()
+                             (std::forward<decltype(graph)>(graph), index_map);
+                     })();
+                run_action<>()
+                    (*this,
+                     [&](auto&& graph)
+                     {
+                         return do_write_to_binary_file()
+                             (stream, std::forward<decltype(graph)>(graph),
+                              index_map, get_num_vertices(), directed, agprops,
+                              avprops, aeprops);
+                     })();
             }
             else
             {
-                run_action<>()(*this, std::bind(do_write_to_binary_file(),
-                                                std::ref(stream),
-                                                std::placeholders::_1,
-                                                _vertex_index,
-                                                get_num_vertices(),
-                                                directed,
-                                                std::ref(agprops),
-                                                std::ref(avprops),
-                                                std::ref(aeprops)))();
+                run_action<>()
+                    (*this,
+                     [&](auto&& graph)
+                     {
+                         return do_write_to_binary_file()
+                             (stream, std::forward<decltype(graph)>(graph),
+                              _vertex_index, get_num_vertices(), directed,
+                              agprops, avprops, aeprops);
+                     })();
             }
 
             _directed = directed;
@@ -564,16 +562,24 @@ void GraphInterface::write_to_file(string file, boost::python::object pfile,
             {
                 // vertex indexes must be between the [0, HardNumVertices(g)] range
                 vector_property_map<size_t> index_map(_vertex_index);
-                run_action<>()(*this, boost::bind<void>(generate_index(),
-                                                        _1, index_map))();
+                run_action<>()
+                    (*this,
+                     [&](auto&& graph)
+                     {
+                         return generate_index()
+                             (std::forward<decltype(graph)>(graph), index_map);
+                     })();
                 if (format == "dot")
                     graphviz_insert_index(dp, index_map);
 
                 run_action<>()
-                    (*this, boost::bind<void>(do_write_to_file(),
-                                              boost::ref(stream), _1,
-                                              index_map, boost::ref(dp),
-                                              format))();
+                    (*this,
+                     [&](auto&& graph)
+                     {
+                         return do_write_to_file()
+                             (stream, std::forward<decltype(graph)>(graph),
+                              index_map, dp, format);
+                     })();
             }
             else
             {
@@ -581,10 +587,13 @@ void GraphInterface::write_to_file(string file, boost::python::object pfile,
                     graphviz_insert_index(dp, _vertex_index);
 
                 run_action<>()
-                    (*this, boost::bind<void>(do_write_to_file(),
-                                              boost::ref(stream), _1,
-                                              _vertex_index,  boost::ref(dp),
-                                              format))();
+                    (*this,
+                     [&](auto&& graph)
+                     {
+                         return do_write_to_file()
+                             (stream, std::forward<decltype(graph)>(graph),
+                              _vertex_index, dp, format);
+                     })();
             }
         }
         stream.reset();
