@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -23,10 +23,6 @@
 #include "graph_util.hh"
 #include "hash_map_wrap.hh"
 
-#include <boost/mpl/for_each.hpp>
-
-#include <boost/python/extract.hpp>
-
 using namespace std;
 using namespace boost;
 using namespace graph_tool;
@@ -69,8 +65,13 @@ void perfect_ehash(GraphInterface& gi, boost::any prop, boost::any hprop,
                    boost::any& dict)
 {
     run_action<graph_tool::detail::always_directed>()
-        (gi, std::bind<void>(do_perfect_ehash(), std::placeholders::_1,
-         std::placeholders::_2, std::placeholders::_3, std::ref(dict)),
-         edge_properties(), writable_edge_scalar_properties())
-        (prop, hprop);
+        (gi,
+         [&](auto&& graph, auto&& a2, auto&& a3)
+         {
+             return do_perfect_ehash()
+                 (std::forward<decltype(graph)>(graph),
+                  std::forward<decltype(a2)>(a2),
+                  std::forward<decltype(a3)>(a3), dict);
+         },
+         edge_properties(), writable_edge_scalar_properties())(prop, hprop);
 }
