@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -33,8 +33,13 @@ void edge_property_map_values(GraphInterface& g, boost::any src_prop,
                               boost::any tgt_prop, boost::python::object mapper)
 {
     run_action<graph_tool::detail::always_directed_never_reversed>()
-        (g, std::bind(do_map_values(), std::placeholders::_1, std::placeholders::_2,
-                      std::placeholders::_3, std::ref(mapper)),
-         edge_properties(), writable_edge_properties())
-        (src_prop, tgt_prop);
+        (g,
+         [&](auto&& graph, auto&& a2, auto&& a3)
+         {
+             return do_map_values()
+                 (std::forward<decltype(graph)>(graph),
+                  std::forward<decltype(a2)>(a2),
+                  std::forward<decltype(a3)>(a3), mapper);
+         },
+         edge_properties(), writable_edge_properties())(src_prop, tgt_prop);
 }
