@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -22,8 +22,6 @@
 
 #include "graph_properties_group.hh"
 
-#include <boost/python/extract.hpp>
-
 using namespace std;
 using namespace boost;
 using namespace graph_tool;
@@ -44,14 +42,28 @@ void ungroup_vector_property(GraphInterface& g, boost::any vector_prop,
 {
     if (edge)
         run_action<graph_tool::detail::always_directed_never_reversed>()
-            (g, bind(do_group_vector_property<boost::mpl::false_,boost::mpl::true_>(),
-                     std::placeholders::_1, std::placeholders::_2, std::placeholders::_3, pos),
-             edge_vector_properties(), writable_edge_properties())
-            (vector_prop, prop);
+            (g,
+             [&](auto&& graph, auto&& a2, auto&& a3)
+             {
+                 return do_group_vector_property<boost::mpl::false_,
+                                                 boost::mpl::true_>()(
+                     std::forward<decltype(graph)>(graph),
+                     std::forward<decltype(a2)>(a2),
+                     std::forward<decltype(a3)>(a3), pos);
+             },
+             edge_vector_properties(),
+             writable_edge_properties())(vector_prop, prop);
     else
         run_action<graph_tool::detail::always_directed_never_reversed>()
-            (g, bind(do_group_vector_property<boost::mpl::false_,boost::mpl::false_>(),
-                     std::placeholders::_1, std::placeholders::_2, std::placeholders::_3, pos),
-             vertex_vector_properties(), writable_vertex_properties())
-            (vector_prop, prop);
+            (g,
+             [&](auto&& graph, auto&& a2, auto&& a3)
+             {
+                 return do_group_vector_property<boost::mpl::false_,
+                                                 boost::mpl::false_>()(
+                     std::forward<decltype(graph)>(graph),
+                     std::forward<decltype(a2)>(a2),
+                     std::forward<decltype(a3)>(a3), pos);
+             },
+             vertex_vector_properties(),
+             writable_vertex_properties())(vector_prop, prop);
 }
