@@ -9,14 +9,11 @@
 //           Andrew Lumsdaine
 //           Tiago de Paula Peixoto
 
-#include <boost/python.hpp>
-#include <boost/variant.hpp>
 #include <expat.h>
 #include <boost/graph/graphml.hpp>
 #include <boost/algorithm/string/replace.hpp>
 #include <boost/archive/iterators/xml_escape.hpp>
 #include <boost/archive/iterators/ostream_iterator.hpp>
-#include <boost/archive/iterators/insert_linebreaks.hpp>
 #include <sstream>
 
 #include "base64.hh"
@@ -295,7 +292,7 @@ private:
             {
                 id = lexical_cast<size_t>(std::string(v,1));
             }
-            catch (bad_lexical_cast)
+            catch (bad_lexical_cast&)
             {
                 std::stringstream s;
                 s << "on line " << XML_GetCurrentLineNumber(m_parser)
