@@ -25,30 +25,20 @@
 //         Ronald Garcia
 //
 
-#include <boost/ref.hpp>
-#include <boost/function/function2.hpp>
 #include <boost/version.hpp>
 #if (BOOST_VERSION >= 104000)
 #   include <boost/property_map/dynamic_property_map.hpp>
 #else
 #   include <boost/dynamic_property_map.hpp>
 #endif
-#include <boost/graph/graph_traits.hpp>
-#include <boost/detail/workaround.hpp>
 #include <boost/algorithm/string/case_conv.hpp>
-#include <algorithm>
-#include <exception> // for std::exception
 #include <string>
 #include <vector>
 #include <set>
 #include <utility>
 #include <map>
-#include <iostream>
-#include <cstdlib>
 #include <boost/throw_exception.hpp>
 #include <boost/regex.hpp>
-#include <boost/function.hpp>
-#include <boost/bind.hpp>
 #include <boost/graph/graphviz.hpp>
 
 namespace boost {
