@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -16,7 +16,6 @@
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 #include "graph_filtering.hh"
-#include "graph_python_interface.hh"
 
 #include <boost/python.hpp>
 #include <boost/graph/astar_search.hpp>
@@ -71,14 +70,17 @@ void a_star_search_implicit(GraphInterface& g, size_t source,
                             python::object cmb, python::object zero,
                             python::object inf, python::object h)
 {
-    run_action<graph_tool::all_graph_views,mpl::true_>()
-        (g, std::bind(do_astar_search(), std::placeholders::_1, source,
-                      std::placeholders::_2, make_pair(pred, cost),
-                      weight,
-                      AStarVisitorWrapper(g, vis),
-                      make_pair(AStarCmp(cmp),
-                                AStarCmb(cmb)),
-                      make_pair(zero, inf), h, std::ref(g)),
+    run_action<graph_tool::all_graph_views, mpl::true_>()
+        (g,
+         [&](auto&& graph, auto&& a2)
+         {
+             return do_astar_search()
+                 (std::forward<decltype(graph)>(graph), source,
+                  std::forward<decltype(a2)>(a2), make_pair(pred, cost), weight,
+                  AStarVisitorWrapper(g, vis),
+                  make_pair(AStarCmp(cmp), AStarCmb(cmb)), make_pair(zero, inf),
+                  h, g);
+         },
          writable_vertex_properties())(dist_map);
 }
 
