@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -33,9 +33,14 @@ using namespace graph_tool;
 python::object do_label_components(GraphInterface& gi, boost::any prop)
 {
     vector<size_t> hist;
-    run_action<graph_tool::all_graph_views,mpl::true_>()
-        (gi, std::bind(label_components(), std::placeholders::_1,
-                       std::placeholders::_2, std::ref(hist)),
+    run_action<graph_tool::all_graph_views, mpl::true_>()
+        (gi,
+         [&](auto&& graph, auto&& a2)
+         {
+             return label_components()
+                 (std::forward<decltype(graph)>(graph),
+                  std::forward<decltype(a2)>(a2), hist);
+         },
          writable_vertex_scalar_properties())(prop);
     return wrap_vector_owned(hist);
 }
@@ -46,19 +51,29 @@ do_label_biconnected_components(GraphInterface& gi, boost::any comp,
 {
     vector<size_t> hist;
     run_action<graph_tool::detail::never_directed>()
-        (gi, std::bind(label_biconnected_components(), std::placeholders::_1,
-                       std::placeholders::_2, std::placeholders::_3,
-                       std::ref(hist)),
+        (gi,
+         [&](auto&& graph, auto&& a2, auto&& a3)
+         {
+             return label_biconnected_components()
+                 (std::forward<decltype(graph)>(graph),
+                  std::forward<decltype(a2)>(a2),
+                  std::forward<decltype(a3)>(a3), hist);
+         },
          writable_edge_scalar_properties(),
-         writable_vertex_scalar_properties())
-        (comp, art);
+         writable_vertex_scalar_properties())(comp, art);
     return wrap_vector_owned(hist);
 }
 
 void do_label_out_component(GraphInterface& gi, size_t root, boost::any prop)
 {
-    run_action<graph_tool::all_graph_views,mpl::true_>()
-        (gi, std::bind(label_out_component(), std::placeholders::_1, std::placeholders::_2, root),
+    run_action<graph_tool::all_graph_views, mpl::true_>()
+        (gi,
+         [&](auto&& graph, auto&& a2)
+         {
+             return label_out_component()
+                 (std::forward<decltype(graph)>(graph),
+                  std::forward<decltype(a2)>(a2), root);
+         },
          writable_vertex_scalar_properties())(prop);
 }
 
@@ -67,9 +82,15 @@ void do_label_attractors(GraphInterface& gi, boost::any cprop, python::object oa
 
     multi_array_ref<bool,1> avec = get_array<bool,1>(oavec);
 
-    run_action<>()(gi, std::bind(label_attractors(), std::placeholders::_1,
-                                 std::placeholders::_2, avec),
-                   vertex_scalar_properties())(cprop);
+    run_action<>()
+        (gi,
+         [&](auto&& graph, auto&& a2)
+         {
+             return label_attractors()
+                 (std::forward<decltype(graph)>(graph),
+                  std::forward<decltype(a2)>(a2), avec);
+         },
+         vertex_scalar_properties())(cprop);
 }
 
 void export_components()
