@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -30,7 +30,6 @@
 #include <boost/graph/dijkstra_shortest_paths_no_color_map.hpp>
 #include <boost/graph/bellman_ford_shortest_paths.hpp>
 #include <boost/graph/dag_shortest_paths.hpp>
-#include <boost/python/stl_iterator.hpp>
 #include <boost/python.hpp>
 
 #if (BOOST_VERSION >= 106000)
@@ -457,33 +456,49 @@ void get_dists(GraphInterface& gi, size_t source, boost::python::object tgt,
     if (weight.empty())
     {
         run_action<>()
-            (gi, std::bind(do_bfs_search(), std::placeholders::_1, source, tgt, gi.get_vertex_index(),
-                           std::placeholders::_2, pmap.get_unchecked(num_vertices(gi.get_graph())),
-                           max_dist, std::ref(reached)),
-             writable_vertex_scalar_properties())
-            (dist_map);
+            (gi,
+             [&](auto&& graph, auto&& a2)
+             {
+                 return do_bfs_search()
+                     (std::forward<decltype(graph)>(graph), source, tgt,
+                      gi.get_vertex_index(), std::forward<decltype(a2)>(a2),
+                      pmap.get_unchecked(num_vertices(gi.get_graph())),
+                      max_dist, reached);
+             },
+             writable_vertex_scalar_properties())(dist_map);
     }
     else
     {
         if (bf)
         {
             run_action<>()
-                (gi, std::bind(do_bf_search(), std::placeholders::_1, source,
-                               std::placeholders::_2, pmap.get_unchecked(num_vertices(gi.get_graph())),
-                               std::placeholders::_3),
+                (gi,
+                 [&](auto&& graph, auto&& a2, auto&& a3)
+                 {
+                     return do_bf_search()
+                         (std::forward<decltype(graph)>(graph), source,
+                          std::forward<decltype(a2)>(a2),
+                          pmap.get_unchecked(num_vertices(gi.get_graph())),
+                          std::forward<decltype(a3)>(a3));
+                 },
                  writable_vertex_scalar_properties(),
-                 edge_scalar_properties())
-                (dist_map, weight);
+                 edge_scalar_properties())(dist_map, weight);
         }
         else
         {
             run_action<>()
-                (gi, std::bind(do_djk_search(), std::placeholders::_1, source, tgt, gi.get_vertex_index(),
-                               std::placeholders::_2, pmap.get_unchecked(num_vertices(gi.get_graph())),
-                               std::placeholders::_3, max_dist, std::ref(reached), dag),
+                (gi,
+                 [&](auto&& graph, auto&& a2, auto&& a3)
+                 {
+                     return do_djk_search()
+                         (std::forward<decltype(graph)>(graph), source, tgt,
+                          gi.get_vertex_index(), std::forward<decltype(a2)>(a2),
+                          pmap.get_unchecked(num_vertices(gi.get_graph())),
+                          std::forward<decltype(a3)>(a3), max_dist, reached,
+                          dag);
+                 },
                  writable_vertex_scalar_properties(),
-                 edge_scalar_properties())
-                (dist_map, weight);
+                 edge_scalar_properties())(dist_map, weight);
         }
     }
 }
