@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -174,8 +174,13 @@ void maximal_vertex_set(GraphInterface& gi, boost::any mvs, bool high_deg,
                         rng_t& rng)
 {
     run_action<>()
-        (gi, std::bind(do_maximal_vertex_set(), std::placeholders::_1, gi.get_vertex_index(),
-                       std::placeholders::_2, high_deg, std::ref(rng)),
+        (gi,
+         [&](auto&& graph, auto&& a2)
+         {
+             return do_maximal_vertex_set()
+                 (std::forward<decltype(graph)>(graph), gi.get_vertex_index(),
+                  std::forward<decltype(a2)>(a2), high_deg, rng);
+         },
          writable_vertex_scalar_properties())(mvs);
 }
 
