@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -15,7 +15,6 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-#include <boost/python.hpp>
 #include <boost/graph/transitive_closure.hpp>
 
 #include "graph.hh"
@@ -40,6 +39,10 @@ struct get_transitive_closure
 void transitive_closure(GraphInterface& gi, GraphInterface& tcgi)
 {
     run_action<graph_tool::detail::always_directed>()
-        (gi, std::bind(get_transitive_closure(), std::placeholders::_1,
-                       std::ref(tcgi.get_graph())))();
+        (gi,
+         [&](auto&& graph)
+         {
+             return get_transitive_closure()
+                 (std::forward<decltype(graph)>(graph), tcgi.get_graph());
+         })();
 }
