@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -66,14 +66,17 @@ try:
     libgv.agedge.restype = ptype
     libgv.agget.restype = ptype
     libgv.agstrdup_html.restype = ptype
+    libgv.agstrdup_html.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
+    libgv.agraphof.restype = ctypes.c_void_p
+    libgv.agraphof.argtypes = [ctypes.c_void_p]
     # create a context to use the whole time (if we keep freeing and recreating
     # it, we will hit a memory leak in graphviz)
     gvc = libgv.gvContext()
 
     try:
         gv_new_api = True
-        libgv_directed = libgv.Agdirected
-        libgv_undirected = libgv.Agundirected
+        libgv_directed = ctypes.c_int.in_dll(libgv, "Agdirected")
+        libgv_undirected = ctypes.c_int.in_dll(libgv, "Agundirected")
     except AttributeError:
         gv_new_api = False
         libgv_directed = 1
@@ -85,14 +88,15 @@ except OSError:
     warnings.warn(msg, ImportWarning)
 
 
-def htmlize(val):
+def htmlize(elem, val):
     if len(val) >= 2 and val[0] == "<" and val[-1] == ">":
-        return ctypes.string_at(libgv.agstrdup_html(val[1:-1]))
+        g = libgv.agraphof(elem)
+        return ctypes.string_at(libgv.agstrdup_html(g, str(val[1:-1]).encode("utf8")))
     return val
 
 
 def aset(elem, attr, value):
-    v = htmlize(str(value)).encode("utf8")
+    v = htmlize(elem, str(value))
     libgv.agsafeset(elem, str(attr).encode("utf8"), v, v)
 
 
@@ -232,14 +236,13 @@ def graphviz_draw(g, pos=None, size=(15, 15), pin=False, layout=None,
         Scalar edge property map which specifies the order with which edges
         are drawn.
     output : string (default: ``""``)
-        Output file name.
+        Output file name. If ``None`` then no output is produced.
     output_format : string (default: ``"auto"``)
         Output file format. Possible values are ``"auto"``, ``"xlib"``,
         ``"ps"``, ``"svg"``, ``"svgz"``, ``"fig"``, ``"mif"``, ``"hpgl"``,
         ``"pcl"``, ``"png"``, ``"gif"``, ``"dia"``, ``"imap"``, ``"cmapx"``. If
         the value is ``"auto"``, the format is guessed from the ``output``
-        parameter, or ``xlib`` if it is empty. If the value is ``None``, no
-        output is produced.
+        parameter, or ``xlib`` if it is empty.
     fork : bool (default: ``False``)
         If ``True``, the program is forked before drawing. This is used as a
         work-around for a bug in graphviz, where the ``exit()`` function is
@@ -555,11 +558,11 @@ def graphviz_draw(g, pos=None, size=(15, 15), pin=False, layout=None,
                                        output.encode("utf8"))
                 data = open(output).read()
                 os.remove(output)
-        else:
+        elif output is not None:
             if output_format == "auto":
                 if output == "":
                     output_format = "xlib"
-                elif output is not None:
+                else:
                     output_format = output.split(".")[-1]
 
             # if using xlib we need to fork the process, otherwise good ol'
@@ -572,7 +575,7 @@ def graphviz_draw(g, pos=None, size=(15, 15), pin=False, layout=None,
                     os._exit(0)  # since we forked, it's good to be sure
                 if output_format != "xlib":
                     os.wait()
-            elif output is not None:
+            else:
                 libgv.gvRenderFilename(gvc, gvg, output_format.encode("utf8"),
                                        output.encode("utf8"))
 
