@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -33,6 +33,8 @@ Summary
    generate_sbm
    generate_maxent_sbm
    solve_sbm_fugacities
+   generate_knn
+   generate_triadic_closure
    predecessor_tree
    line_graph
    graph_union
@@ -52,7 +54,8 @@ from .. dl_import import dl_import
 dl_import("from . import libgraph_tool_generation")
 
 from .. import Graph, GraphView, _check_prop_scalar, _prop, _limit_args, \
-    _gt_type, _get_rng, Vector_double
+    _gt_type, _get_rng, Vector_double, VertexPropertyMap
+from .. stats import remove_parallel_edges
 import inspect
 import types
 import numpy
@@ -61,11 +64,11 @@ import scipy.optimize
 import scipy.sparse
 
 __all__ = ["random_graph", "random_rewire", "generate_sbm",
-           "solve_sbm_fugacities", "generate_maxent_sbm", "predecessor_tree",
-           "line_graph", "graph_union", "triangulation", "lattice",
-           "geometric_graph", "price_network", "complete_graph",
-           "circular_graph", "condensation_graph"]
-
+           "solve_sbm_fugacities", "generate_maxent_sbm", "generate_knn",
+           "generate_triadic_closure", "predecessor_tree", "line_graph",
+           "graph_union", "triangulation", "lattice", "geometric_graph",
+           "price_network", "complete_graph", "circular_graph",
+           "condensation_graph"]
 
 def random_graph(N, deg_sampler, directed=True,
                  parallel_edges=False, self_loops=False, block_membership=None,
@@ -102,13 +105,13 @@ def random_graph(N, deg_sampler, directed=True,
         If ``True``, parallel edges are allowed.
     self_loops : bool (optional, default: ``False``)
         If ``True``, self-loops are allowed.
-    block_membership : list or :class:`~numpy.ndarray` or function (optional, default: ``None``)
+    block_membership : list or :class:`numpy.ndarray` or function (optional, default: ``None``)
         If supplied, the graph will be sampled from a stochastic blockmodel
         ensemble, and this parameter specifies the block membership of the
         vertices, which will be passed to the
         :func:`~graph_tool.generation.random_rewire` function.
 
-        If the value is a list or a :class:`~numpy.ndarray`, it must have
+        If the value is a list or a :class:`numpy.ndarray`, it must have
         ``len(block_membership) == N``, and the values will define to which
         block each vertex belongs.
 
@@ -1121,7 +1124,7 @@ def solve_sbm_fugacities(b, ers, out_degs=None, in_degs=None, multigraph=False,
     References
     ----------
     .. [peixoto-latent-2020] Tiago P. Peixoto, "Latent Poisson models for
-       networks with heterogeneous density", :arxiv:`2002.07803`
+       networks with heterogeneous density", :doi:`10.1103/PhysRevE.102.012309`, :arxiv:`2002.07803`
     """
 
     b = numpy.asarray(b, dtype="int32")
@@ -1314,7 +1317,7 @@ def generate_maxent_sbm(b, mrs, out_theta, in_theta=None, directed=False,
     References
     ----------
     .. [peixoto-latent-2020] Tiago P. Peixoto, "Latent Poisson models for
-       networks with heterogeneous density", :arxiv:`2002.07803`
+       networks with heterogeneous density", :doi:`10.1103/PhysRevE.102.012309`, :arxiv:`2002.07803`
 
     Examples
     --------
@@ -1378,7 +1381,176 @@ def generate_maxent_sbm(b, mrs, out_theta, in_theta=None, directed=False,
                        multigraph, self_loops, _get_rng())
     return g
 
+def generate_knn(points, k, dist=None, exact=False, r=.5, epsilon=.001,
+                 directed=False, cache_dist=True):
+    r"""Generate a graph of k-nearest neighbors from a set of multidimensional points.
 
+    Parameters
+    ----------
+    points : iterable of lists (or :class:`numpy.ndarray`) of dimension :math:`N\times D` or ``int``
+        Points of dimension :math:`D` to be considered. If the parameter `dist`
+        is passed, this should be just an `int` containing the number of points.
+    k : ``int``
+        Number of nearest neighbors.
+    dist : function (optional, default: ``None``)
+        If given, this should be a function that returns the distance between
+        two points. The arguments of this function should just be two integers,
+        corresponding to the vertex index. In this case the value of ``points``
+        should just be the total number of points. If ``dist is None``, then the
+        L2-norm (Euclidean distance) is used.
+    exact : ``bool`` (optional, default: ``False``)
+        If ``False``, an fast approximation will be used, otherwise an exact but
+        slow algorithm will be used.
+    r : ``float`` (optional, default: ``.5``)
+        If ``exact is False``, this specifies the fraction of randomly chosen
+        neighbors that are used for the search.
+    epsilon : ``float`` (optional, default: ``.001``)
+        If ``exact is False``, this determines the convergence criterion used by
+        the algorithm. When the fraction of updated neighbors drops below this
+        value, the algorithm stops.
+    directed : ``bool`` (optional, default: ``False``)
+        If ``True`` a directed version of the graph will be returned, otherwise
+        the graph is undirected.
+    cache_dist : ``bool`` (optional, default: ``True``)
+        If ``True``, an internal cache of the distance values are kept,
+        implemented as a hash table.
+
+    Returns
+    -------
+    g : :class:`~graph_tool.Graph`
+        The k-nearest neighbors graph.
+    w : :class:`~graph_tool.EdgePropertyMap`
+        Edge property map with the computed distances.
+
+    Notes
+    -----
+
+    The approximate version of this algorithm is based on
+    [[dong-efficient-2020]_, and has an (empirical) run-time of
+    :math:`O(N^{1.14})`. The exact version has a complexity of :math:`O(N^2)`.
+
+    If enabled during compilation, this algorithm runs in parallel.
+
+    References
+    ----------
+    .. [dong-efficient-2020] Wei Dong, Charikar Moses, and Kai Li, "Efficient
+       k-nearest neighbor graph construction for generic similarity measures",
+       In Proceedings of the 20th international conference on World wide web
+       (WWW '11). Association for Computing Machinery, New York, NY, USA,
+       577–586, (2011) :doi:`https://doi.org/10.1145/1963405.1963487`
+
+    Examples
+    --------
+
+    >>> points = np.random.random((1000, 10))
+    >>> g, w = gt.generate_knn(points, k=5)
+
+    """
+
+    if dist is not None:
+        N = points
+        points = dist
+    else:
+        points = numpy.asarray(points, dtype="float")
+        N = points.shape[0]
+
+    g = Graph()
+    g.add_vertex(N)
+    w = g.new_ep("double")
+
+    if exact:
+        libgraph_tool_generation.gen_knn_exact(g._Graph__graph, points, k,
+                                               _prop("e", g, w))
+    else:
+        libgraph_tool_generation.gen_knn(g._Graph__graph, points, k, r, epsilon,
+                                         cache_dist, _prop("e", g, w), _get_rng())
+
+    if not directed:
+        g.set_directed(False)
+        remove_parallel_edges(g)
+
+    return g, w
+
+def generate_triadic_closure(g, t, probs=True, curr=None, ego=None):
+    r"""Closes open triads in a graph, according to an ego-based process.
+
+    Parameters
+    ----------
+    g : :class:`~graph_tool.Graph`
+        Graph to be modified.
+    t : :class:`~graph_tool.VertexPropertyMap` or scalar
+        Vertex property map (or scalar value) with the ego closure propensities
+        for every node.
+    probs : ``boolean`` (optional, default: ``False``)
+        If ``True``, the values of ``t`` will be interpreted as the independent
+        probability of connecting two neighbors of the respective
+        vertex. Otherwise, it will determine the integer number of pairs of
+        neighbors that will be closed.
+    curr : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
+        If given, this should be a boolean-valued edge property map, such that
+        triads will only be closed if they contain at least one edge marged with
+        the value ``True``.
+    ego : :class:`~graph_tool.EdgePropertyMap` (optional, default: ``None``)
+        If given, this should be an integer-valued edge property map, containing
+        the ego vertex for each closed triad, which will be updated with the new
+        generation.
+
+    Returns
+    -------
+    ego : :class:`~graph_tool.EdgePropertyMap`
+        Integer-valued edge property map, containing the ego vertex for each
+        closed triad.
+
+    Notes
+    -----
+
+    This algorithm [peixoto-disentangling-2021]_ consist in, for each node
+    ``u``, connecting all its neighbors with probability given by ``t[u]``. In
+    case ``probs == False``, then ``t[u]`` indicates the number of random pairs
+    of neighbors of ``u`` that are connected. This algorithm may generate
+    parallel edges.
+
+    This algorithm has a complexity of :math:`O(N\left<k^2\right>)`, where
+    :math:`\left<k^2\right>` is the second moment of the degree distribution.
+
+    References
+    ----------
+    .. [peixoto-disentangling-2021] Tiago P. Peixoto, "Disentangling homophily,
+       community structure and triadic closure in networks", :arxiv:`2101.02510`
+
+    Examples
+    --------
+
+    >>> g = gt.collection.data["karate"].copy()
+    >>> gt.generate_triadic_closure(g, .5)
+    <...>
+    >>> gt.graph_draw(g, g.vp.pos, output="karate-triadic.png")
+    <...>
+
+    .. figure:: karate-triadic.*
+       :align: center
+       :width: 40%
+
+       Karate club network with added random triadic closure edges.
+
+    """
+    if not isinstance(t, VertexPropertyMap):
+        t = g.new_vp("double" if probs else "int64_t", val=t)
+    _check_prop_scalar(t, name="t")
+    if curr is None:
+        curr = g.new_ep("bool", val=True)
+    if curr.value_type() != "bool":
+        curr = curr.copy("bool")
+    if ego is None:
+        ego = g.new_ep("int64_t", val=-1)
+    if ego.value_type() != "int64_t":
+        ego = ego.copy("int64_t")
+    libgraph_tool_generation.gen_triadic_closure(g._Graph__graph,
+                                                 _prop("e", g, curr),
+                                                 _prop("e", g, ego),
+                                                 _prop("v", g, t),
+                                                 probs, _get_rng())
+    return ego
 
 def predecessor_tree(g, pred_map):
     """Return a graph from a list of predecessors given by the ``pred_map`` vertex property."""
@@ -1650,7 +1822,7 @@ def triangulation(points, type="simple", periodic=False):
 
     Parameters
     ----------
-    points : :class:`~numpy.ndarray`
+    points : :class:`numpy.ndarray`
         Point set for the triangulation. It may be either a N x d array, where N
         is the number of points, and d is the space dimension (either 2 or 3).
     type : string (optional, default: ``'simple'``)
@@ -1768,7 +1940,7 @@ def lattice(shape, periodic=False):
 
     Parameters
     ----------
-    shape : list or :class:`~numpy.ndarray`
+    shape : list or :class:`numpy.ndarray`
         List of sizes in each dimension.
     periodic : bool (optional, default: ``False``)
         If ``True``, periodic boundary conditions will be used.
@@ -1926,13 +2098,13 @@ def geometric_graph(points, radius, ranges=None):
 
     Parameters
     ----------
-    points : list or :class:`~numpy.ndarray`
+    points : list or :class:`numpy.ndarray`
         List of points. This must be a two-dimensional array, where the rows are
         coordinates in a N-dimensional space.
     radius : float
         Pairs of points with an euclidean distance lower than this parameters
         will be connected.
-    ranges : list or :class:`~numpy.ndarray` (optional, default: ``None``)
+    ranges : list or :class:`numpy.ndarray` (optional, default: ``None``)
         If provided, periodic boundary conditions will be assumed, and the
         values of this parameter it will be used as the ranges in all
         dimensions. It must be a two-dimensional array, where each row will
