@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -127,7 +127,9 @@ State classes
    :nosignatures:
 
    ~graph_tool.inference.uncertain_blockmodel.LatentMultigraphBlockState
+   ~graph_tool.inference.latent_layers.LatentClosureBlockState
    ~graph_tool.inference.uncertain_blockmodel.MeasuredBlockState
+   ~graph_tool.inference.latent_layers.MeasuredClosureBlockState
    ~graph_tool.inference.uncertain_blockmodel.MixedMeasuredBlockState
    ~graph_tool.inference.uncertain_blockmodel.UncertainBlockState
    ~graph_tool.inference.uncertain_blockmodel.UncertainBaseState
@@ -200,6 +202,9 @@ __all__ = ["minimize_blockmodel_dl",
            "PseudoIsingBlockState",
            "CIsingGlauberBlockState",
            "PseudoCIsingBlockState",
+           "LatentLayerBaseState",
+           "LatentClosureBlockState",
+           "MeasuredClosureBlockState",
            "mcmc_equilibrate",
            "mcmc_anneal",
            "mcmc_multilevel",
@@ -257,3 +262,4 @@ from . latent_multigraph import *
 from . partition_centroid import *
 from . partition_modes import *
 from . planted_partition import *
+from . latent_layers import *
