@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2020 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2021 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -66,7 +66,7 @@ class NestedBlockState(object):
 
         if bs is None:
             if base_type is OverlapBlockState or state_args.get("overlap", False):
-                b = zeros(2 * g.num_vertices(), dtype="int")
+                b = zeros(2 * g.num_edges(), dtype="int")
             else:
                 b = zeros(g.num_vertices(), dtype="int")
             bs = [b] + [zeros(1, dtype="int")] * int(ceil(log2(len(b))))
@@ -825,7 +825,8 @@ class NestedBlockState(object):
             c = [c * 2 ** l for l in range(0, len(self.levels))]
 
         if kwargs.pop("dispatch", True):
-            if _bm_test():
+            test = kwargs.get("test", True)
+            if _bm_test() and test:
                 kwargs = dict(kwargs, test=False)
                 entropy_args = kwargs.get("entropy_args", {})
                 Si = self.entropy(**entropy_args)
@@ -833,7 +834,7 @@ class NestedBlockState(object):
             dS, nattempts, nmoves = self._h_sweep(lambda s, **a: s.mcmc_sweep(**a),
                                                   c=c, **kwargs)
 
-            if _bm_test():
+            if _bm_test() and test:
                 Sf = self.entropy(**entropy_args)
                 assert math.isclose(dS, (Sf - Si), abs_tol=1e-8), \
                     "inconsistent entropy delta %g (%g): %s" % (dS, Sf - Si,
@@ -876,14 +877,15 @@ class NestedBlockState(object):
             c = [c * 2 ** l for l in range(0, len(self.levels))]
 
         if kwargs.pop("dispatch", True):
-            if _bm_test():
+            test = kwargs.get("test", True)
+            if _bm_test() and test:
                 kwargs = dict(kwargs, test=False)
                 entropy_args = kwargs.get("entropy_args", {})
                 Si = self.entropy(**entropy_args)
 
             dS, nattempts, nmoves = self._h_sweep(lambda s, **a: s.multiflip_mcmc_sweep(**a),
                                                   c=c, **kwargs)
-            if _bm_test():
+            if _bm_test() and test:
                 Sf = self.entropy(**entropy_args)
                 assert math.isclose(dS, (Sf - Si), abs_tol=1e-8), \
                     r"inconsistent entropy delta %g (%g): %s" % (dS, Sf - Si,
